netapp_ontap.models.iscsi_connection_interface API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.iscsi_connection_interface`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class IscsiConnectionInterfaceSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the IscsiConnectionInterface object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `ip: IscsiConnectionInterfaceIp GET POST PATCH`

    The IP information. ONTAP only supports port 3260.

  `links: SelfLink GET`

    The links field of the iscsi_connection_interface.

  `name: str GET`

    The name of the interface.

    Example: lif1

  `uuid: str GET`

    The UUID that uniquely identifies the interface.

    Example: 1cd8a442-86d1-11e0-ae1c-123478563412